@@ -10,12 +10,12 @@ from edpm.engine.env_gen import Prepend, Set, Append
 from edpm.engine.git_cmake_recipe import GitCmakeRecipe
 
 
-class EigenRecipe(GitCmakeRecipe):
-    """Provides data for building and installing Eicgen3 framework"""
+class IrtRecipe(GitCmakeRecipe):
+    """Indirect Ray Tracing code for EPIC event reconstruction"""
 
     def __init__(self):
-        super(EigenRecipe, self).__init__('irt')
-        self.config['branch'] = 'v1.0.0'
+        super(IrtRecipe, self).__init__('irt')
+        self.config['branch'] = 'v1.0.1'
         self.config['repo_address'] = 'https://github.com/eic/irt.git'
 
     @staticmethod
